Learn R Programming

statwitness (version 0.1.0)

audit_plan: Preview an Automatic Audit Plan

Description

Fits the requested model and reports which registered audits are applicable.

Usage

audit_plan(
  formula,
  data,
  focus = NULL,
  family = NULL,
  weights = NULL,
  method = "auto",
  engine = NULL,
  control = NULL,
  audit_level = c("standard", "core", "thorough")
)

Value

A data frame of selected and skipped tests with reasons.

Arguments

formula

A model formula.

data

A data frame.

focus

An optional coefficient, variable, or omnibus term.

family

An optional model family.

weights

Optional analysis weights.

method

Requested fitting method.

engine

Optional custom fitting function.

control

Optional model-specific control object.

audit_level

Audit breadth used to construct the plan.