Fits the requested model and reports which registered audits are applicable.
audit_plan(
formula,
data,
focus = NULL,
family = NULL,
weights = NULL,
method = "auto",
engine = NULL,
control = NULL,
audit_level = c("standard", "core", "thorough")
)A data frame of selected and skipped tests with reasons.
A model formula.
A data frame.
An optional coefficient, variable, or omnibus term.
An optional model family.
Optional analysis weights.
Requested fitting method.
Optional custom fitting function.
Optional model-specific control object.
Audit breadth used to construct the plan.